@@ -2,7 +2,7 @@ ranef.rma.uni <- function(object, level, digits, transf, targs, ...) {
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
-   .chkclass(class(object), must="rma.uni", notav="rma.uni.selmodel")
+   .chkclass(class(object), must="rma.uni", notav=c("rma.gen", "rma.uni.selmodel"))
 
    x <- object
 
