@@ -1,11 +1,15 @@
 ### library(metafor); library(testthat); Sys.setenv(NOT_CRAN="true")
 
-### see also: http://www.metafor-project.org/doku.php/plots:meta_analytic_scatterplot
+### see also: https://www.metafor-project.org/doku.php/plots:meta_analytic_scatterplot
+
+source("settings.r")
 
 context("Checking plots example: meta-analytic scatterplot")
 
 test_that("plot can be drawn.", {
 
+   expect_equivalent(TRUE, TRUE) # avoid 'Empty test' message
+
    skip_on_cran()
 
    opar <- par(no.readonly=TRUE)
@@ -13,9 +17,6 @@ test_that("plot can be drawn.", {
    ### adjust margins so the space is better used
    par(mar=c(5,5,1,2))
 
-   ### load BCG vaccine data
-   data(dat.bcg, package="metafor")
-
    ### calculate log risk ratios and corresponding sampling variances
    dat <- escalc(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg)
 
@@ -25,15 +26,19 @@ test_that("plot can be drawn.", {
    ### calculate predicted risk ratios for 0 to 60 degrees absolute latitude
    preds <- predict(res, newmods=c(0:60), transf=exp)
 
-   ### calculate point sizes by rescaling the standard errors
-   wi    <- 1/sqrt(dat$vi)
-   size  <- 0.5 + 3.0 * (wi - min(wi))/(max(wi) - min(wi))
+   ### radius of points will be proportional to the inverse standard errors
+   ### hence the area of the points will be proportional to inverse variances
+   size <- 1 / sqrt(dat$vi)
+   size <- size / max(size)
 
-   ### plot the risk ratios against absolute latitude
-   plot(dat$ablat, exp(dat$yi), pch=19, cex=size,
+   ### set up plot (risk ratios on y-axis, absolute latitude on x-axis)
+   plot(NA, NA, xlim=c(10,60), ylim=c(0.2,1.6),
         xlab="Absolute Latitude", ylab="Risk Ratio",
         las=1, bty="l", log="y")
 
+   ### add points
+   symbols(dat$ablat, exp(dat$yi), circles=size, inches=FALSE, add=TRUE, bg="black")
+
    ### add predicted values (and corresponding CI bounds)
    lines(0:60, preds$pred)
    lines(0:60, preds$ci.lb, lty="dashed")
@@ -50,3 +55,5 @@ test_that("plot can be drawn.", {
    par(opar)
 
 })
+
+rm(list=ls())
